@@ -220,6 +220,7 @@ Tellico::Data::FieldVec BibtexCollection::defaultFields() {
 //  list.append(field);
 
   field = new Field(QString::fromLatin1("keyword"), i18n("Keywords"));
+  field->setProperty(QString::fromLatin1("bibtex"), QString::fromLatin1("keywords"));
   field->setCategory(i18n(bibtex_misc));
   field->setFlags(Field::AllowCompletion | Field::AllowMultiple | Field::AllowGrouped);
   list.append(field);
@@ -297,6 +298,7 @@ int BibtexCollection::sameEntry(Data::EntryPtr entry1_, Data::EntryPtr entry2_)
   if(Entry::compareValues(entry1_, entry2_, QString::fromLatin1("isbn"),  this) > 0 ||
      Entry::compareValues(entry1_, entry2_, QString::fromLatin1("lccn"),  this) > 0 ||
      Entry::compareValues(entry1_, entry2_, QString::fromLatin1("doi"),   this) > 0 ||
+     Entry::compareValues(entry1_, entry2_, QString::fromLatin1("pmid"),  this) > 0 ||
      Entry::compareValues(entry1_, entry2_, QString::fromLatin1("arxiv"), this) > 0) {
     return 100; // good match
   }
