@@ -25,8 +25,7 @@ namespace {
 using Tellico::Data::ComicBookCollection;
 
 ComicBookCollection::ComicBookCollection(bool addFields_, const QString& title_ /*=null*/)
-   : Collection(title_, i18n("Comics")) {
-  setTitle(title_.isNull() ? i18n("My Comic Books") : title_);
+   : Collection(title_.isEmpty() ? i18n("My Comic Books") : title_) {
   if(addFields_) {
     addFields(defaultFields());
   }
