@@ -23,8 +23,7 @@ namespace {
 using Tellico::Data::GameCollection;
 
 GameCollection::GameCollection(bool addFields_, const QString& title_ /*=null*/)
-   : Collection(title_, i18n("Games")) {
-  setTitle(title_.isNull() ? i18n("My Games") : title_);
+   : Collection(title_.isEmpty() ? i18n("My Games") : title_) {
   if(addFields_) {
     addFields(defaultFields());
   }
