@@ -14,12 +14,11 @@
 #ifndef TELLICO_DETAILEDENTRYITEM_H
 #define TELLICO_DETAILEDENTRYITEM_H
 
+class QTime;
 class QTimer;
 
 #include "entryitem.h"
 
-#include <qdatetime.h>
-
 namespace Tellico {
 
 class DetailedListView;
@@ -40,10 +39,6 @@ public:
   virtual void paintCell(QPainter* p, const QColorGroup& cg,
                          int column, int width, int align);
 
-  virtual int compare(QListViewItem* item, int col, bool ascending) const;
-
-  DetailedListView* listView() const;
-
 private:
   /**
    * Paints a focus indicator on the rectangle (current item). Disable for current items.
