@@ -226,6 +226,13 @@ Tellico::Data::EntryPtr ArxivFetcher::fetchEntry(uint uid_) {
       }
     }
   }
+  QRegExp versionRx(QRegExp(QString::fromLatin1("v\\d+$")));
+  // if the original search was not for a versioned ID, remove it
+  if(m_key != ArxivID || !m_value.contains(versionRx)) {
+    QString arxiv = entry->field(QString::fromLatin1("arxiv"));
+    arxiv.remove(versionRx);
+    entry->setField(QString::fromLatin1("arxiv"), arxiv);
+  }
   return entry;
 }
 
