@@ -116,6 +116,7 @@ void EntrezFetcher::search(FetchKey key_, const QString& value_) {
       u.addQueryItem(QString::fromLatin1("field"), QString::fromLatin1("pmid"));
       break;
 
+    case DOI:
     case Raw:
       u.setQuery(u.query() + '&' + value_);
       break;
@@ -342,8 +343,8 @@ Tellico::Data::EntryPtr EntrezFetcher::fetchEntry(uint uid_) {
   u.addQueryItem(QString::fromLatin1("db"),         m_dbname);
   u.addQueryItem(QString::fromLatin1("id"),         QString::number(id));
 #endif
-  // now it's sychronous
-  QString xmlOutput = FileHandler::readTextFile(u);
+  // now it's sychronous, and we know that it's utf8
+  QString xmlOutput = FileHandler::readTextFile(u, false /*quiet*/, true /*utf8*/);
   if(xmlOutput.isEmpty()) {
     kdWarning() << "EntrezFetcher::fetchEntry() - unable to download " << u << endl;
     return 0;
@@ -446,6 +447,12 @@ void EntrezFetcher::updateEntry(Data::EntryPtr entry_) {
     return;
   }
 
+  s = entry_->field(QString::fromLatin1("doi"));
+  if(!s.isEmpty()) {
+    search(DOI, s);
+    return;
+  }
+
   s = entry_->field(QString::fromLatin1("title"));
   if(!s.isEmpty()) {
     search(Title, s);
