@@ -65,12 +65,12 @@ public:
 
   // create fetcher for updating an entry
   FetcherVec createUpdateFetchers(int collType);
-  FetcherVec createUpdateFetchers(int collType, Type type);
+  FetcherVec createUpdateFetchers(int collType, FetchKey key);
   Fetcher::Ptr createUpdateFetcher(int collType, const QString& source);
 
   static QString typeName(Type type);
-  static QPixmap fetcherIcon(Fetch::Type type);
-  static QPixmap fetcherIcon(Fetch::Fetcher::CPtr ptr);
+  static QPixmap fetcherIcon(Fetch::Type type, int iconGroup=3 /*Small*/, int size=0 /* default */);
+  static QPixmap fetcherIcon(Fetch::Fetcher::CPtr ptr, int iconGroup=3 /*Small*/, int size=0 /* default*/);
 
 signals:
   void signalStatus(const QString& status);
