@@ -35,6 +35,7 @@
 #include "../gui/lineedit.h"
 #include "../gui/combobox.h"
 #include "../isbnvalidator.h"
+#include "../lccnvalidator.h"
 
 #include <klocale.h>
 #include <kstandarddirs.h>
@@ -133,7 +134,7 @@ void Z3950Fetcher::saveConfigHook(KConfigGroup& config_) {
 }
 
 void Z3950Fetcher::search(FetchKey key_, const QString& value_) {
-#if HAVE_YAZ
+#ifdef HAVE_YAZ
   m_started = true;
   m_done = false;
   if(m_host.isEmpty() || m_dbname.isEmpty()) {
@@ -186,6 +187,22 @@ void Z3950Fetcher::search(FetchKey key_, const QString& value_) {
         }
       }
       break;
+    case LCCN:
+      {
+        m_pqn.truncate(0);
+        QString s = m_value;
+        s.remove('-');
+        QStringList lccnList = QStringList::split(QString::fromLatin1("; "), s);
+        while(!lccnList.isEmpty()) {
+          m_pqn += QString::fromLatin1(" @or @attr 1=9 ") + lccnList.front();
+          if(lccnList.count() > 1) {
+            m_pqn += QString::fromLatin1(" @or");
+          }
+          m_pqn += QString::fromLatin1(" @attr 1=9 ") + LCCNValidator::formalize(lccnList.front());
+          lccnList.pop_front();
+        }
+      }
+      break;
     case Keyword:
       m_pqn = QString::fromLatin1("@attr 1=1016 ") + svalue;
       break;
@@ -214,7 +231,7 @@ void Z3950Fetcher::search(FetchKey key_, const QString& value_) {
 }
 
 void Z3950Fetcher::continueSearch() {
-#if HAVE_YAZ
+#ifdef HAVE_YAZ
   m_started = true;
   process();
 #endif
@@ -467,14 +484,21 @@ void Z3950Fetcher::updateEntry(Data::EntryPtr entry_) {
   if(!isbn.isEmpty()) {
     search(Fetch::ISBN, isbn);
     return;
-  } else {
-    // optimistically try searching for title and rely on Collection::sameEntry() to figure things out
-    QString t = entry_->field(QString::fromLatin1("title"));
-    if(!t.isEmpty()) {
-      search(Fetch::Title, t);
-      return;
-    }
   }
+
+  QString lccn = entry_->field(QString::fromLatin1("lccn"));
+  if(!lccn.isEmpty()) {
+    search(Fetch::LCCN, lccn);
+    return;
+  }
+
+  // optimistically try searching for title and rely on Collection::sameEntry() to figure things out
+  QString t = entry_->field(QString::fromLatin1("title"));
+  if(!t.isEmpty()) {
+    search(Fetch::Title, t);
+    return;
+  }
+
   myDebug() << "Z3950Fetcher::updateEntry() - insufficient info to search" << endl;
   emit signalDone(this); // always need to emit this if not continuing with the search
 }
