@@ -16,7 +16,10 @@
 
 #include <klineedit.h>
 
-#include <qlabel.h>
+#include <qstring.h>
+
+class KAction;
+class KSpell;
 
 namespace Tellico {
   namespace GUI {
@@ -33,6 +36,11 @@ public:
   virtual void setText(const QString& text);
   void setHint(const QString& hint);
 
+  // by default, spell check is not allowed, and no popupmenu item is created
+  void setAllowSpellCheck(bool b) { m_allowSpellCheck = b; }
+  // spell check may be allowed but disabled
+  void setEnableSpellCheck(bool b) { m_enableSpellCheck = b; }
+
 public slots:
   void clear();
 
@@ -40,10 +48,23 @@ protected:
   virtual void focusInEvent(QFocusEvent* event);
   virtual void focusOutEvent(QFocusEvent* event);
   virtual void drawContents(QPainter* painter);
+  virtual QPopupMenu* createPopupMenu();
+
+private slots:
+  void slotCheckSpelling();
+  void slotSpellCheckReady(KSpell* spell);
+  void slotSpellCheckDone(const QString& text);
+  void spellCheckerMisspelling(const QString& text, const QStringList&, unsigned int pos);
+  void spellCheckerCorrected(const QString& oldText, const QString& newText, unsigned int pos);
+  void spellCheckerFinished();
 
 private:
   QString m_hint;
   bool m_drawHint;
+  KAction* m_spellAction;
+  bool m_allowSpellCheck;
+  bool m_enableSpellCheck;
+  KSpell* m_spell;
 };
 
   } // end namespace
