@@ -138,7 +138,6 @@ Tellico::Import::Importer* ImportDialog::importer(Import::Format format_, const
       break;
 
     case Import::Bibtex:
-      CHECK_SIZE;
       importer = new Import::BibtexImporter(urls_);
       break;
 
@@ -334,6 +333,12 @@ Tellico::Import::FormatMap ImportDialog::formatMap() {
   return map;
 }
 
+bool ImportDialog::formatImportsText(Import::Format format_) {
+  return format_ != Import::AMC &&
+         format_ != Import::Griffith &&
+         format_ != Import::PDF;
+}
+
 QString ImportDialog::startDir(Import::Format format_) {
   if(format_ == Import::GCfilms) {
     QDir dir = QDir::home();
