@@ -18,7 +18,7 @@
 #include "../imagefactory.h"
 #include "../image.h"
 #include "../tellico_utils.h"
-//#include "../tellico_debug.h"
+#include "../tellico_debug.h"
 #include "../progressmanager.h"
 
 #include <klocale.h>
