@@ -53,7 +53,7 @@ void report_error (bt_errclass class,
 
 void general_error (bt_errclass class,
                     char * filename, int line, const char * item_desc, int item,
-                    const char * format, ...);
+                    char * format, ...);
 void error (bt_errclass class, char * filename, int line, char * format, ...);
 void ast_error (bt_errclass class, AST * ast, char * format, ...);
 
