@@ -34,8 +34,6 @@ public:
 
   // no options
   virtual QWidget* widget(QWidget*, const char*) { return 0; }
-  virtual void readOptions(KConfig*) {}
-  virtual void saveOptions(KConfig*) {}
 
   void setIncludeImages(bool b) { m_includeImages = b; }
 
